@@ -27,9 +27,9 @@
 #'  \href{https://cyrillagger.github.io/scDiffCom/articles/scDiffCom-vignette.html}{vignette}).
 #'
 #'  Data extraction. The UMI or read counts matrix is extracted from
-#'  the assay \code{seurat_assay} and the slot \code{seurat_slot}. By default,
+#'  the assay \code{seurat_assay} and the layer \code{seurat_layer}. By default,
 #'  it is assumed that \code{seurat_object} contains log1p-transformed
-#'  normalized data in the slot "data" of its assay "RNA". If \code{log_scale}
+#'  normalized data in the layer "data" of its assay "RNA". If \code{log_scale}
 #'  is \code{FALSE} (as recommended), the data are \code{expm1()} transformed
 #'  in order to recover normalized values not in log scale.
 #'
@@ -48,8 +48,9 @@
 #' @param seurat_object Seurat object that must contain normalized
 #'  data and relevant \code{meta.data} columns (see below). Gene names must be
 #'   MGI (mouse) or HGNC (human) approved symbols.
-#' @param LRI_species Either \code{"mouse"}, \code{"human"} or \code{"rat"}. Indicates which
-#'  LRI database to use and corresponds to the species of the \code{seurat_object}.
+#' @param LRI_species Either \code{"mouse"}, \code{"human"}, \code{"rat"} or \code{"custom"}.
+#' Indicates which LRI database to use and corresponds to the species of the \code{seurat_object}.
+#' Use \code{"custom"} at your own risk to use your own LRI table (see \code{custom_LRI_tables}).
 #' @param seurat_celltype_id Name of the \code{meta.data} column in
 #'  \code{seurat_object} that contains cell-type annotations
 #'  (e.g.: \code{"CELL_TYPE"}).
@@ -75,14 +76,16 @@
 #'  be returned (\code{"scDiffCom_object"} by default).
 #' @param seurat_assay Assay of \code{seurat_object} from which to extract data.
 #'  See Details for an explanation on how data are extracted based on the three
-#'  parameters \code{seurat_assay}, \code{seurat_slot} and \code{log_scale}.
-#' @param seurat_slot Slot of \code{seurat_object} from which to extract data.
+#'  parameters \code{seurat_assay}, \code{seurat_layer} and \code{log_scale}.
+#' @param seurat_slot `r lifecycle::badge("deprecated")` `seurat_slot` is no
+#'   longer supported; use `seurat_layer` instead.
+#' @param seurat_layer Layer of \code{seurat_object} from which to extract data.
 #'  See Details for an explanation on how data are extracted based on the three
-#'  parameters \code{seurat_assay}, \code{seurat_slot} and \code{log_scale}.
+#'  parameters \code{seurat_assay}, \code{seurat_layer} and \code{log_scale}.
 #' @param log_scale When \code{FALSE} (the default, recommended), data are
 #'  treated as normalized but not log1p-transformed. See Details for an
 #'  explanation on how data are extracted based on the three
-#'  parameters \code{seurat_assay}, \code{seurat_slot} and \code{log_scale}.
+#'  parameters \code{seurat_assay}, \code{seurat_layer} and \code{log_scale}.
 #' @param score_type Metric used to compute cell-cell interaction (CCI) scores.
 #'  Can either be \code{"geometric_mean"} (default) or \code{"arithmetic_mean"}.
 #'  It is strongly recommended to use the geometric mean, especially when
@@ -128,6 +131,17 @@
 #' @param seed Set a random seed (\code{42} by default) to obtain reproducible
 #' results.
 #' @param verbose If \code{TRUE} (default), print progress messages.
+#' @param custom_LRI_tables A list containing a LRI table and, if known,
+#' tables with annotations supplied by the user. Overwrite
+#' \code{LRI_species} and the corresponding internal LRI table. Use to
+#' your own risk! Must contain at least the following named item:
+#'  \enumerate{
+#'    \item \code{LRI}: a data.table of LRIs
+#'  }
+#' The data.table of LRIs must be in the same format as the internal
+#' LRI_tables, namely with the columns "LRI", "LIGAND_1", "LIGAND_2",
+#' "RECEPTOR_1", "RECEPTOR_2", "RECEPTOR_3". Other named data.tables
+#' can be supplied for over-representation analysis (ORA) purposes.
 #'
 #' @return An S4 object of class \code{\link{scDiffCom-class}}.
 #' @export
@@ -152,7 +166,8 @@ run_interaction_analysis <- function(
   iterations = 1000,
   scdiffcom_object_name = "scDiffCom_object",
   seurat_assay = "RNA",
-  seurat_slot = "data",
+  seurat_layer = "data",
+  seurat_slot = deprecated(),
   log_scale = FALSE,
   score_type = "geometric_mean",
   threshold_min_cells = 5,
@@ -163,20 +178,29 @@ run_interaction_analysis <- function(
   threshold_logfc = log(1.5),
   return_distributions = FALSE,
   seed = 42,
-  verbose = TRUE
+  verbose = TRUE,
+  custom_LRI_tables = NULL
 ) {
   if (!methods::is(seurat_object, "Seurat")) {
     stop(
       "'seurat_object' must be an object of class Seurat"
       )
   }
+  if (lifecycle::is_present(seurat_slot)) {
+    lifecycle::deprecate_warn(
+      "1.2.0",
+      "run_interaction_analysis(seurat_slot)",
+      "run_interaction_analysis(seurat_layer)"
+    )
+    seurat_layer <- seurat_slot
+  }
   analysis_parameters <- list(
     LRI_species = LRI_species,
     seurat_celltype_id = seurat_celltype_id,
     seurat_condition_id = seurat_condition_id,
     object_name = scdiffcom_object_name,
     seurat_assay = seurat_assay,
-    seurat_slot = seurat_slot,
+    seurat_layer = seurat_layer,
     log_scale = log_scale,
     score_type = score_type,
     threshold_min_cells = threshold_min_cells,
@@ -188,7 +212,8 @@ run_interaction_analysis <- function(
     threshold_logfc = threshold_logfc,
     return_distributions = return_distributions,
     seed = seed,
-    verbose = verbose
+    verbose = verbose,
+    custom_LRI_tables = custom_LRI_tables
   )
   check_parameters <- validate_parameters(
     params = analysis_parameters,
@@ -204,14 +229,29 @@ run_interaction_analysis <- function(
   } else {
     analysis_parameters <- check_parameters$params
   }
-  if (LRI_species == "human") {
-    LRI_table <- copy(scDiffCom::LRI_human$LRI_curated)
-  }
-  if (LRI_species == "mouse") {
-    LRI_table <- copy(scDiffCom::LRI_mouse$LRI_curated)
-  }
-  if (LRI_species == "rat") {
-    LRI_table <- copy(scDiffCom::LRI_rat$LRI_curated)
+  if (analysis_parameters$LRI_species != "custom") {
+    if (!is.null(analysis_parameters$custom_LRI_tables)) {
+      stop(
+        "LRI_species is not 'custom' but a custom LRI table was supplied."
+        )
+    }
+    if (LRI_species == "human") {
+      LRI_table <- copy(scDiffCom::LRI_human$LRI_curated)
+    }
+    if (LRI_species == "mouse") {
+      LRI_table <- copy(scDiffCom::LRI_mouse$LRI_curated)
+    }
+    if (LRI_species == "rat") {
+      LRI_table <- copy(scDiffCom::LRI_rat$LRI_curated)
+    }
+  } else {
+    if (is.null(analysis_parameters$custom_LRI_tables)) {
+      stop(
+        "LRI_species is 'custom' but no custom LRI table was supplied."
+        )
+    }
+    LRI_table <- copy(analysis_parameters$custom_LRI_tables$LRI)
+    if (verbose) message("Using custom LRI table. Use at your own risk!")
   }
   set.seed(seed)
   object <- run_internal_raw_analysis(
@@ -243,7 +283,7 @@ run_internal_raw_analysis <- function(
     cond1_name = params$seurat_condition_id$cond1_name,
     cond2_name = params$seurat_condition_id$cond2_name,
     assay = params$seurat_assay,
-    slot = params$seurat_slot,
+    layer = params$seurat_layer,
     log_scale = params$log_scale,
     threshold_min_cells = as.integer(params$threshold_min_cells),
     LRI_table = LRI_table,
