@@ -223,7 +223,7 @@ combine_LR_db <- function(
     c("SOURCE") := do.call(paste, c(.SD, sep = ";")),
     .SDcols = col_source
   ]
-  LR_full[, c("SOURCE") := gsub("NA|NA;|;NA", "", SOURCE)]
+  LR_full[, c("SOURCE") := gsub("NA|NA;|;NA", "", SOURCE, useBytes = TRUE)]
   col_anno <- paste0("ANNOTATION_", db_names)
   LR_full[
     ,
@@ -411,9 +411,9 @@ combine_LR_db <- function(
       }
     )
   ]
-  LR_full[, SOURCE := gsub("\u00a0", "", SOURCE)]
-  LR_full[, SOURCE := gsub(")", "", SOURCE, fixed = TRUE)]
-  LR_full[, SOURCE := gsub(";;", ";", SOURCE, fixed = TRUE)]
+  LR_full[, SOURCE := gsub("\u00a0", "", SOURCE, , useBytes = TRUE)]
+  LR_full[, SOURCE := gsub(")", "", SOURCE, fixed = TRUE, useBytes = TRUE)]
+  LR_full[, SOURCE := gsub(";;", ";", SOURCE, fixed = TRUE, useBytes = TRUE)]
   LR_full[
     ,
     SOURCE := sapply(
@@ -508,9 +508,9 @@ prepare_LR_connectomeDB2020 <- function(
       "LIGAND_1", "RECEPTOR_1"
     )
   }
-  LR[, SOURCE := gsub("\\s", "", SOURCE)]
+  LR[, SOURCE := gsub("\\s", "", SOURCE, useBytes = TRUE)]
   LR[, SOURCE := paste0("PMID:", SOURCE)]
-  LR[, SOURCE := gsub(",", ";PMID:", SOURCE)]
+  LR[, SOURCE := gsub(",", ";PMID:", SOURCE, useBytes = TRUE)]
   return(
     list(
       retrieved_date = retrieved_date,
@@ -1193,18 +1193,18 @@ prepare_LR_SingleCellSignalR <- function(
   one2one
 ) {
   LR_SORTED <- SOURCE <- PMIDs <- L1 <- R1 <- NULL
-  if (!requireNamespace("SingleCellSignalR", quietly = TRUE)) {
-    stop(
-      paste0(
-        "Package \"SingleCellSignalR\" needed for this function to work.",
-        "Please install it."
-      ),
-      call. = FALSE
-    )
-  }
+  # if (!requireNamespace("SingleCellSignalR", quietly = TRUE)) {
+  #   stop(
+  #     paste0(
+  #       "Package \"SingleCellSignalR\" needed for this function to work.",
+  #       "Please install it."
+  #     ),
+  #     call. = FALSE
+  #   )
+  # }
   retrieved_date <- as.Date("2021-03-22")
   retrieved_from <- "SingleCellSignalR::LRdb"
-  LR <- SingleCellSignalR::LRdb
+  LR <- SingleCellSignalR_human
   setDT(LR)
   #there are 19 genes that are not HGNC approved symbol, we change them
   LR[LR == "BY55"] <- "CD160"
@@ -1683,11 +1683,15 @@ get_KEGG_PWS_interactions <- function(
       }
     )
   )
-  LR_KEGG_PW[
-    KEGG_PW,
-    on = "KEGG_ID",
-    KEGG_NAME := i.KEGG_NAME
-  ]
+  if (nrow(LR_KEGG_PW) == 0) {
+    LR_KEGG_PW == NULL
+  } else {
+    LR_KEGG_PW[
+      KEGG_PW,
+      on = "KEGG_ID",
+      KEGG_NAME := i.KEGG_NAME
+    ]
+  }
   return(LR_KEGG_PW)
 }
 
@@ -1807,7 +1811,7 @@ get_GO_interactions <- function(
     # Don't use ancestors
     ALL_LR_genes_info_unique = unique(ALL_LR_genes_info$mgi_symbol)
     ALL_LR_genes_info_as_list = sapply(
-      ALL_LR_genes_info_unique, 
+      ALL_LR_genes_info_unique,
       function(gene) {
         ALL_LR_genes_info[mgi_symbol == gene]$go_id
       }
