@@ -9,7 +9,7 @@ validate_parameters <- function(
     "seurat_celltype_id",
     "seurat_condition_id",
     "seurat_assay",
-    "seurat_slot",
+    "seurat_layer",
     "log_scale",
     "score_type",
     "threshold_min_cells",
@@ -21,7 +21,8 @@ validate_parameters <- function(
     "threshold_logfc",
     "return_distributions",
     "seed",
-    "verbose"
+    "verbose",
+    "custom_LRI_tables"
   )
   params_names_additional <- c(
     "conditional_analysis",
@@ -45,8 +46,8 @@ validate_parameters <- function(
   if (!is.character(params$object_name) | length(params$object_name) != 1) {
     res <- c(res, "'object_name' must be a character vector of length 1")
   }
-  if (!(params$LRI_species %in% c("mouse", "human", "rat"))) {
-    res <- c(res, "'LRI_species' must be either 'mouse', 'rat', or 'human'")
+  if (!(params$LRI_species %in% c("mouse", "human", "rat", "custom"))) {
+    res <- c(res, "'LRI_species' must be either 'mouse', 'rat', 'human' or 'custom'")
   }
   if (!is.character(params$seurat_celltype_id) |
       length(params$seurat_celltype_id) != 1) {
@@ -93,8 +94,8 @@ validate_parameters <- function(
       "'seurat_assay' must be NULL or a character vector of length 1"
     )
   }
-  if (!(params$seurat_slot %in% c("counts", "data"))) {
-    res <- c(res, "'seurat_slot' must be either 'data' or 'counts'")
+  if (!(params$seurat_layer %in% c("counts", "data"))) {
+    res <- c(res, "'seurat_layer' must be either 'data' or 'counts'")
   }
   if (!is.logical(params$log_scale) | length(params$log_scale) != 1) {
     res <- c(res, "'log_scale' must be a logical vector of length 1")
@@ -180,7 +181,7 @@ validate_parameters <- function(
     ) {
     res <- c(res, "'threshold_p_value_de' must be a numeric in ]0,1]")
   }
-  if (
+  if(
     !is.numeric(params$threshold_logfc) |
     length(params$threshold_logfc) != 1
     ) {
@@ -198,19 +199,34 @@ validate_parameters <- function(
       )
   }
   if(from_inputs) {
-    if (!is.numeric(params$seed) | length(params$seed) > 1) {
+    if(!is.numeric(params$seed) | length(params$seed) > 1) {
       res <- c(res, "'seed' must be a numeric vector of length 1")
     } else if (params$seed < 0 | params$seed %% 1 != 0) {
       res <- c(res, "'seed' must be a non-negative integer")
     }
   } else {
-    if (!is.numeric(params$seed)) {
+    if(!is.numeric(params$seed)) {
       res <- c(res, "'seed' must be a numeric vector")
     }
   }
   if(!is.logical(params$verbose) | length(params$verbose) != 1) {
     res <- c(res, "'verbose' must be a logical vector of length 1")
   }
+  if(!is.null(params$custom_LRI_tables)) {
+    if(!is.list(params$custom_LRI_tables)) {
+      res <- c(
+        res,
+        "'custom_LRI_table must be a list"
+        )
+    } else{
+      if(!methods::is(params$custom_LRI_table$LRI, "data.table")) {
+        res <- c(
+          res,
+          "'custom_LRI_table$LRI' must be a data.table"
+          )
+      }
+    }
+  }
   if(!from_inputs) {
     if(
       !is.logical(params$conditional_analysis) |
