@@ -18,7 +18,7 @@ parameters_mode <- list(
     iterations = 100.2,
     object_name = 4,
     seurat_assay = list("RNA"),
-    seurat_slot = "count",
+    seurat_layer = "count",
     log_scale = "TRUE",
     score_type = "geom",
     threshold_min_cells = -5,
@@ -29,7 +29,8 @@ parameters_mode <- list(
     threshold_logfc = 0,
     return_distributions = "FALSE",
     seed = 5.5,
-    verbose = "TRUE"
+    verbose = "TRUE",
+    custom_LRI_tables = "something_wrong"
   ),
   cond_stat = list(
     LRI_species = "mouse",
@@ -42,7 +43,7 @@ parameters_mode <- list(
     iterations = 10,
     object_name = "scdiffcom_cond_stat",
     seurat_assay = "RNA",
-    seurat_slot = "data",
+    seurat_layer = "data",
     log_scale = FALSE,
     score_type = "geometric_mean",
     threshold_min_cells = 5,
@@ -53,7 +54,8 @@ parameters_mode <- list(
     threshold_logfc = log(1.5),
     return_distributions = FALSE,
     seed = 42,
-    verbose = TRUE
+    verbose = TRUE,
+    custom_LRI_tables = NULL
   ),
   cond_nostat = list(
     LRI_species = "mouse",
@@ -66,7 +68,7 @@ parameters_mode <- list(
     iterations = 0,
     object_name = "scdiffcom_cond_nostat",
     seurat_assay = "RNA",
-    seurat_slot = "data",
+    seurat_layer = "data",
     log_scale = FALSE,
     score_type = "geometric_mean",
     threshold_min_cells = 5,
@@ -77,7 +79,8 @@ parameters_mode <- list(
     threshold_logfc = log(1.5),
     return_distributions = FALSE,
     seed = 42,
-    verbose = FALSE
+    verbose = FALSE,
+    custom_LRI_tables = NULL
   ),
   nocond_stat = list(
     LRI_species = "mouse",
@@ -86,7 +89,7 @@ parameters_mode <- list(
     iterations = 10,
     object_name = "scdiffcom_nocond_stat",
     seurat_assay = "RNA",
-    seurat_slot = "data",
+    seurat_layer = "data",
     log_scale = FALSE,
     score_type = "geometric_mean",
     threshold_min_cells = 5,
@@ -97,7 +100,8 @@ parameters_mode <- list(
     threshold_logfc = log(1.5),
     return_distributions = FALSE,
     seed = 42,
-    verbose = FALSE
+    verbose = FALSE,
+    custom_LRI_tables = NULL
   ),
   nocond_nostat = list(
     LRI_species = "mouse",
@@ -106,7 +110,7 @@ parameters_mode <- list(
     iterations = 0,
     object_name = "scdiffcom_nocond_nostat",
     seurat_assay = "RNA",
-    seurat_slot = "data",
+    seurat_layer = "data",
     log_scale = FALSE,
     score_type = "geometric_mean",
     threshold_min_cells = 5,
@@ -117,7 +121,8 @@ parameters_mode <- list(
     threshold_logfc = log(1.5),
     return_distributions = FALSE,
     seed = 42,
-    verbose = FALSE
+    verbose = FALSE,
+    custom_LRI_tables = NULL
   )
 )
 
@@ -152,7 +157,7 @@ test_that(
     )
     expect_length(
       parameters_mode_validated$wrong,
-      18
+      19
     )
   }
 )
@@ -181,7 +186,7 @@ inputs_test <- lapply(
       cond1_name = param$seurat_condition_id$cond1_name,
       cond2_name = param$seurat_condition_id$cond2_name,
       assay = param$seurat_assay,
-      slot = param$seurat_slot,
+      layer = param$seurat_layer,
       log_scale = param$log_scale,
       threshold_min_cells = param$threshold_min_cells,
       LRI_table = LRI_mouse$LRI_curated,
@@ -621,7 +626,29 @@ test_that(
 
 test_that(
   "run_interaction_analysis is running correctly", {
+    res <- run_interaction_analysis(
+      seurat_object = seurat_test,
+      LRI_species = "mouse",
+      seurat_celltype_id = "cell_type",
+      seurat_condition_id = list(
+        column_name = "age_group",
+        cond1_name = "YOUNG",
+        cond2_name = "OLD"
+      ),
+      iterations = 100
+    )
     expect_s4_class(
+      res,
+     "scDiffCom"
+    )
+  }
+)
+
+## Check the use of custom_LRI_table ####
+
+test_that(
+  "run_interaction_analysis returns error if custom_LRI_tables$LRI is not a data.table", {
+    expect_error(
       run_interaction_analysis(
         seurat_object = seurat_test,
         LRI_species = "mouse",
@@ -630,8 +657,107 @@ test_that(
           column_name = "age_group",
           cond1_name = "YOUNG",
           cond2_name = "OLD"
-        )
+        ),
+        custom_LRI_tables = "something_wrong"
+      )
+    )
+  }
+)
+
+test_that(
+  "run_interaction_analysis returns error if custom_LRI_tables is not a data.table", {
+    expect_error(
+      run_interaction_analysis(
+        seurat_object = seurat_test,
+        LRI_species = "mouse",
+        seurat_celltype_id = "cell_type",
+        seurat_condition_id = list(
+          column_name = "age_group",
+          cond1_name = "YOUNG",
+          cond2_name = "OLD"
+        ),
+        custom_LRI_tables = list(LRI = data.frame(x = 1:4))
+      )
+    )
+  }
+)
+
+test_that(
+  "run_interaction_analysis returns error if custom_LRI_table is not formatted correctly", {
+    expect_error(
+      run_interaction_analysis(
+        seurat_object = seurat_test,
+        LRI_species = "custom",
+        seurat_celltype_id = "cell_type",
+        seurat_condition_id = list(
+          column_name = "age_group",
+          cond1_name = "YOUNG",
+          cond2_name = "OLD"
+        ),
+        custom_LRI_tables = list(LRI = data.table(x = 1:4))
+      )
+    )
+  }
+)
+
+test_that(
+  "error if LRI_species and custom_LRI_table are inconsistent", {
+    expect_error(
+      run_interaction_analysis(
+        seurat_object = seurat_test,
+        LRI_species = "mouse",
+        seurat_celltype_id = "cell_type",
+        seurat_condition_id = list(
+          column_name = "age_group",
+          cond1_name = "YOUNG",
+          cond2_name = "OLD"
+        ),
+        custom_LRI_table = list(LRI = LRI_mouse$LRI_curated[1:500, ])
+      )
+    )
+  }
+)
+
+test_that(
+  "run_interaction_analysis is running correctly with custom LRIs and no annotations", {
+    res <- run_interaction_analysis(
+      seurat_object = seurat_test,
+      LRI_species = "custom",
+      seurat_celltype_id = "cell_type",
+      seurat_condition_id = list(
+        column_name = "age_group",
+        cond1_name = "YOUNG",
+        cond2_name = "OLD"
       ),
+      iterations = 100,
+      custom_LRI_table = list(LRI = LRI_mouse$LRI_curated[1:500, ])
+    )
+    expect_s4_class(
+      res,
+     "scDiffCom"
+    )
+  }
+)
+
+custom_LRI <- LRI_mouse$LRI_curated[1:500, ]
+custom_LRI_GO <- LRI_mouse$LRI_curated_GO[LRI %in% custom_LRI$LRI]
+
+test_that(
+  "run_interaction_analysis is running correctly with custom LRIs and annotations", {
+    res <- run_interaction_analysis(
+      seurat_object = seurat_test,
+      LRI_species = "custom",
+      seurat_celltype_id = "cell_type",
+      seurat_condition_id = list(
+        column_name = "age_group",
+        cond1_name = "YOUNG",
+        cond2_name = "OLD"
+      ),
+      iterations = 100,
+      custom_LRI_table = list(LRI = custom_LRI, my_GO = custom_LRI_GO)
+    )
+    expect_s4_class(
+      res,
      "scDiffCom"
     )
   }
@@ -1038,6 +1164,8 @@ types_of_layout = c(
 test_that(
   "BuildNetwork works and returns a visNetwork object",
   {
+    if (!requireNamespace("visNetwork", quietly = TRUE))
+      testthat::skip("visNetwork not installed")
     lapply(
       types_of_network,
       function(net) {
@@ -1061,18 +1189,11 @@ test_that(
 
 ## Check BuildNetwork internal functions #####
 
-build_interactive_network(
-  object = scdiffcom_objects$cond_stat,
-  network_type = types_of_network[[1]],
-  layout_type = types_of_layout[[2]],
-  class_signature = "scDiffCom",
-  subobject_name = NULL,
-  abbreviation_table = NULL
-)
-
 test_that(
   "No network available for object without statistical analysis",
   {
+    if (!requireNamespace("visNetwork", quietly = TRUE))
+      testthat::skip("visNetwork not installed")
     expect_error(
       build_interactive_network(
         object = scdiffcom_objects$cond_nostat,
